@@ -25,8 +25,8 @@ async def read_item(item_id: str):
     return items[item_id]
 
 
-@app.patch("/items/{item_id}", response_model=Item)
-async def update_item(item_id: str, item: Item):
+@app.patch("/items/{item_id}")
+async def update_item(item_id: str, item: Item) -> Item:
     stored_item_data = items[item_id]
     stored_item_model = Item(**stored_item_data)
     update_data = item.model_dump(exclude_unset=True)
