@@ -1,4 +1,4 @@
-from typing import Annotated, Any, Union
+from typing import Annotated, Any
 
 import pytest
 from dirty_equals import IsOneOf
@@ -51,7 +51,7 @@ def test_required_str_schema(path: str):
     "path",
     ["/required-str", "/model-required-str"],
 )
-def test_required_str_missing(path: str, json: Union[dict[str, Any], None]):
+def test_required_str_missing(path: str, json: dict[str, Any] | None):
     client = TestClient(app)
     response = client.post(path, json=json)
     assert response.status_code == 422
@@ -124,7 +124,7 @@ def test_required_str_alias_schema(path: str):
     "path",
     ["/required-alias", "/model-required-alias"],
 )
-def test_required_alias_missing(path: str, json: Union[dict[str, Any], None]):
+def test_required_alias_missing(path: str, json: dict[str, Any] | None):
     client = TestClient(app)
     response = client.post(path, json=json)
     assert response.status_code == 422
@@ -221,9 +221,7 @@ def test_required_validation_alias_schema(path: str):
         "/model-required-validation-alias",
     ],
 )
-def test_required_validation_alias_missing(
-    path: str, json: Union[dict[str, Any], None]
-):
+def test_required_validation_alias_missing(path: str, json: dict[str, Any] | None):
     client = TestClient(app)
     response = client.post(path, json=json)
     assert response.status_code == 422
@@ -338,7 +336,7 @@ def test_required_alias_and_validation_alias_schema(path: str):
     ],
 )
 def test_required_alias_and_validation_alias_missing(
-    path: str, json: Union[dict[str, Any], None]
+    path: str, json: dict[str, Any] | None
 ):
     client = TestClient(app)
     response = client.post(path, json=json)
