@@ -1,5 +1,3 @@
-from typing import Union
-
 import pytest
 from fastapi import Body, Cookie, FastAPI, Header, Path, Query
 from fastapi.exceptions import FastAPIDeprecationWarning
@@ -117,7 +115,7 @@ def create_app():
 
         @app.get("/query_example/")
         def query_example(
-            data: Union[str, None] = Query(
+            data: str | None = Query(
                 default=None,
                 example="query1",
             ),
@@ -126,7 +124,7 @@ def create_app():
 
     @app.get("/query_examples/")
     def query_examples(
-        data: Union[str, None] = Query(
+        data: str | None = Query(
             default=None,
             examples=["query1", "query2"],
         ),
@@ -137,7 +135,7 @@ def create_app():
 
         @app.get("/query_example_examples/")
         def query_example_examples(
-            data: Union[str, None] = Query(
+            data: str | None = Query(
                 default=None,
                 example="query_overridden",
                 examples=["query1", "query2"],
@@ -149,7 +147,7 @@ def create_app():
 
         @app.get("/header_example/")
         def header_example(
-            data: Union[str, None] = Header(
+            data: str | None = Header(
                 default=None,
                 example="header1",
             ),
@@ -158,7 +156,7 @@ def create_app():
 
     @app.get("/header_examples/")
     def header_examples(
-        data: Union[str, None] = Header(
+        data: str | None = Header(
             default=None,
             examples=[
                 "header1",
@@ -172,7 +170,7 @@ def create_app():
 
         @app.get("/header_example_examples/")
         def header_example_examples(
-            data: Union[str, None] = Header(
+            data: str | None = Header(
                 default=None,
                 example="header_overridden",
                 examples=["header1", "header2"],
@@ -184,7 +182,7 @@ def create_app():
 
         @app.get("/cookie_example/")
         def cookie_example(
-            data: Union[str, None] = Cookie(
+            data: str | None = Cookie(
                 default=None,
                 example="cookie1",
             ),
@@ -193,7 +191,7 @@ def create_app():
 
     @app.get("/cookie_examples/")
     def cookie_examples(
-        data: Union[str, None] = Cookie(
+        data: str | None = Cookie(
             default=None,
             examples=["cookie1", "cookie2"],
         ),
@@ -204,7 +202,7 @@ def create_app():
 
         @app.get("/cookie_example_examples/")
         def cookie_example_examples(
-            data: Union[str, None] = Cookie(
+            data: str | None = Cookie(
                 default=None,
                 example="cookie_overridden",
                 examples=["cookie1", "cookie2"],
